@@ -1,4 +1,4 @@
-# Copyright 2020 Axis Communications AB.
+# Copyright 2020-2021 Axis Communications AB.
 #
 # For a full list of individual contributors, please see the commit history.
 #
@@ -264,9 +264,7 @@ class TestLogUpload(TestCase):
                         test_suite_finished.data.data["persistentLogs"].remove(log)
                         break
                 else:
-                    raise AssertionError(
-                        f"{filename} was not attached to TestSuiteFinished event."
-                    )
+                    raise AssertionError(f"{filename} was not attached to TestSuiteFinished event.")
 
     def test_log_upload_rename_file_too_long(self):
         """Test that log upload works and that it renames too long filenames.
@@ -292,7 +290,7 @@ class TestLogUpload(TestCase):
         )
         suite["recipes"][0]["constraints"][command_index] = {
             "key": "COMMAND",
-            "value": "touch $LOG_PATH/%s.txt" % ("a" * 251),
+            "value": f"touch $LOG_PATH/{'a'*251}.txt",
         }
         # The file that is created will total to '255' characters, the maximum limit, but since
         # ETR attaches the test case name for each log file generated by that test case we will
@@ -302,9 +300,7 @@ class TestLogUpload(TestCase):
             self.logger.info("STEP: Initialize ETR.")
             etr = ETR()
 
-            self.logger.info(
-                "STEP: Run ETR with a suite that creates a file with a too long name."
-            )
+            self.logger.info("STEP: Run ETR with a suite that creates a file with a too long name.")
             self.wait_for_request.return_value = [suite]
             etr.run_etr()
             test_suite_finished = self.get_event(
@@ -416,9 +412,7 @@ class TestLogUpload(TestCase):
             "value": "touch $ARTIFACT_PATH/my_artifact.txt",
         }
         with self.environ(environment):
-            self.logger.info(
-                "STEP: Initialize and run ETR suite which creates an artifact."
-            )
+            self.logger.info("STEP: Initialize and run ETR suite which creates an artifact.")
             etr = ETR()
             etr.run_etr()
             self.logger.info("STEP: Verify that upload works as expected.")
